@@ -45,6 +45,7 @@
 #include <CollectionComboBox>
 #include <Item>
 #include <Akonadi/Calendar/ETMCalendar>
+#include <AkonadiCore/EntityTreeModel>
 
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/MemoryCalendar>
@@ -128,7 +129,7 @@ public:
 IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer, IncidenceDialog *qq)
     : q_ptr(qq)
     , mUi(new Ui::EventOrTodoDesktop)
-    , mCalSelector(new Akonadi::CollectionComboBox)
+    , mCalSelector(new Akonadi::CollectionComboBox(changer ? changer->entityTreeModel() : nullptr))
     , mCloseOnSave(false)
     , mItemManager(new EditorItemManager(this, changer))
     , mEditor(new CombinedIncidenceEditor(qq))
@@ -520,6 +521,28 @@ void IncidenceDialogPrivate::handleItemSaveFinish(EditorItemManager::SaveAction
 {
     Q_Q(IncidenceDialog);
 
+    if ((mEditor->type() == KCalendarCore::Incidence::TypeEvent) &&
+        (mCalSelector->count() > 1) &&
+        (CalendarSupport::KCalPrefs::instance()->defaultCalendarId() == -1)) {
+            const QString collectionName = mCalSelector->currentText();
+            const QString message =
+                xi18nc("@info",
+                      "<para>You have not set a default calendar for your events yet.</para>"
+                      "<para>Setting a default calendar will make creating new events faster and "
+                      "easier with less chance of filing them into the wrong folder.</para>"
+                      "<para>Would you like to set your default events calendar to "
+                      "<resource>%1</resource>?</para>",
+                      collectionName);
+          if (KMessageBox::questionYesNo(q,
+              message,
+              i18nc("@title:window", "Set Default Calendar?"),
+              KStandardGuiItem::yes(), // Make collectionName My Default Calendar
+              KStandardGuiItem::no(),  // Do Not Set a Default Calendar at this Time"
+              QStringLiteral("setDefaultCalendarCollection")) == KMessageBox::Yes) {
+              CalendarSupport::KCalPrefs::instance()->setDefaultCalendarId(mItem.storageCollectionId());
+          }
+    }
+
     if (mCloseOnSave) {
         q->accept();
     } else {
